# deps\_manager

This package runs as CLI for dependency management across Python and C++ projects, abstracting language-specific package manager calls.
Simplified dependency management tasks by enabling dependency operations like installation, uninstallation, listing, updating, and locking.


* [deps\_manager](#deps\_manager)
* [Description](#package-description)
* [Usage](#usage)
* [Installation](#installation)
* [History](#history)
* [Credits](#credits)
* [Licence](#licence)
* [Todo and Possible Future Improvements](#todopossible-future-improvements)
* [FAQ](#faq)


## Package Description
* [deps\_manager](#deps\_manager)

This package runs as CLI for dependency management across Python and C++ projects, abstracting language-specific package manager calls.
Simplified dependency management tasks by enabling dependency operations like installation, uninstallation, listing, updating, and locking.

### Usage
* [deps\_manager](#deps\_manager)

#### From the Command Line

command to get package usage help: ```deps_manager --help```
command to install packages: ```deps-manager python install -r requirements.txt --venv </path/to/virtual/environment>```

### Installation
* [deps\_manager](#deps\_manager)

Install the package with:
```pip3 install deps_manager```

To install from source and develop:
```
git clone git@gitlab.com:harshadatupe8/dependency_manager_cli.git
cd dependency_manager_cli
python3 setup.py sdist bdist_wheel
python3 setup.py develop
```

### System Requirements
* [deps\_manager](#deps\_manager)

## History
* [deps\_manager](#deps\_manager)

## Credits
* [deps\_manager](#deps\_manager)

## License
* [deps\_manager](#deps\_manager)

MIT License

## TODO/Possible Future Improvements
* [deps\_manager](#deps\_manager)
    * Check for dependency security vulnerability.
    * Add integration with a GUI.
    * Solve dependency conflicts.

## FAQ
* [deps\_manager](#deps\_manager)